aboutsummaryrefslogtreecommitdiffstats
path: root/include/media/m5mols.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/media/m5mols.h')
-rw-r--r--include/media/m5mols.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/include/media/m5mols.h b/include/media/m5mols.h
index aac2c0e..544a284 100644
--- a/include/media/m5mols.h
+++ b/include/media/m5mols.h
@@ -1,5 +1,5 @@
/*
- * Driver header for M-5MOLS 8M Pixel camera sensor with ISP
+ * Driver for M5MOLS 8M Pixel camera sensor with ISP
*
* Copyright (C) 2011 Samsung Electronics Co., Ltd.
* Author: HeungJun Kim <riverful.kim@samsung.com>
@@ -17,19 +17,19 @@
#define MEDIA_M5MOLS_H
/**
* struct m5mols_platform_data - platform data for M-5MOLS driver
* @irq: GPIO getting the irq pin of M-5MOLS
* @gpio_reset: GPIO driving the reset pin of M-5MOLS
* @reset_polarity: active state for gpio_rst pin, 0 or 1
* @set_power: an additional callback to the board setup code
* to be called after enabling and before disabling
- * the sensor's supply regulators
+* the sensor device supply regulators
*/
struct m5mols_platform_data {
- int irq;
- int gpio_reset;
- u8 reset_polarity;
int (*set_power)(struct device *dev, int on);
+ int irq;
+ int gpio_rst;
+ bool enable_rst;
};
#endif /* MEDIA_M5MOLS_H */
@@ -17,19 +17,19 @@
#define MEDIA_M5MOLS_H
/**
- * struct m5mols_platform_data - platform data for M-5MOLS driver
- * @irq: GPIO getting the irq pin of M-5MOLS
- * @gpio_reset: GPIO driving the reset pin of M-5MOLS
- * @reset_polarity: active state for gpio_rst pin, 0 or 1
- * @set_power: an additional callback to the board setup code
+* struct m5mols_platform_data - platform data for M5MOLS driver
+* @irq: GPIO getting the irq pin of M5MOLS
+* @gpio_rst: GPIO driving the reset pin of M5MOLS
+ * @enable_rst: the pin state when reset pin is enabled
+* @set_power: an additional callback to a board setup code
* to be called after enabling and before disabling